otcextensions.sdk.mrs.v1.cluster
================================

.. automodule:: otcextensions.sdk.mrs.v1.cluster

The MRS ClusterInfo Class
-------------------------

The ``ClusterInfo`` class inherits from
:class:`~otcextensions.sdk.sdk_resource.Resource`.

.. autoclass:: otcextensions.sdk.mrs.v1.cluster.ClusterInfo
   :members:

.. autoclass:: otcextensions.sdk.mrs.v1.cluster.ParametersSpec
   :members:

The MRS Cluster Class
---------------------

The ``Cluster`` class inherits from
:class:`~otcextensions.sdk.sdk_resource.Resource`.

.. autoclass:: otcextensions.sdk.mrs.v1.cluster.Cluster
   :members:


The MRS Host Class
------------------

The ``Host`` class inherits from
:class:`~otcextensions.sdk.sdk_resource.Resource`.

.. autoclass:: otcextensions.sdk.mrs.v1.cluster.Host
   :members:
